# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-11-15 15:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('request_logger', '0002_auto_20170918_1506'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userrequest',
            name='user',
            field=models.IntegerField(null=True),
        ),
    ]



#!/usr/bin/env python
# vi: et sw=2 fileencoding=utf-8

from __future__ import unicode_literals

from django.db import models


class TruncatingCharField(models.CharField):
    def get_prep_value(self, value):
        value = super(TruncatingCharField,self).get_prep_value(value)
        if value:
            return value[:self.max_length]
        return value


class UserRequest(models.Model):
  user = models.IntegerField(null=True)
  timestamp = models.DateTimeField(auto_now_add=True)
  path = TruncatingCharField(max_length=2047)
  method = TruncatingCharField(max_length=255)
  scheme = TruncatingCharField(max_length=255)
  body = models.TextField()
  content_length = TruncatingCharField(max_length=255)
  content_type = TruncatingCharField(max_length=255)
  http_accept = TruncatingCharField(max_length=255)
  http_accept_encoding = TruncatingCharField(max_length=255)
  http_accept_language = TruncatingCharField(max_length=255)
  http_host = TruncatingCharField(max_length=255)
  http_referer = TruncatingCharField(max_length=2047)
  http_user_agent = TruncatingCharField(max_length=255)
  remote_addr = TruncatingCharField(max_length=255)
  remote_host = TruncatingCharField(max_length=255)
  remote_user = TruncatingCharField(max_length=255)
  server_name = TruncatingCharField(max_length=255)
  server_port = TruncatingCharField(max_length=255)
  post_data = models.TextField()
  get_data = models.TextField()
  cookies = models.TextField()
  encoding = TruncatingCharField(max_length=255)
  is_ajax = models.BooleanField()


  # class UserRequest





# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-09-18 15:06
from __future__ import unicode_literals

from django.db import migrations
import request_logger.models


class Migration(migrations.Migration):

    dependencies = [
        ('request_logger', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userrequest',
            name='content_length',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='content_type',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='encoding',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_accept',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_accept_encoding',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_accept_language',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_host',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_referer',
            field=request_logger.models.TruncatingCharField(max_length=2047),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_user_agent',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='method',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='path',
            field=request_logger.models.TruncatingCharField(max_length=2047),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='remote_addr',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='remote_host',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='remote_user',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='scheme',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='server_name',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='server_port',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='UserRequest',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('timestamp', models.DateTimeField(auto_now_add=True)),
                ('path', models.CharField(max_length=2047)),
                ('method', models.CharField(max_length=255)),
                ('scheme', models.CharField(max_length=255)),
                ('body', models.TextField()),
                ('content_length', models.CharField(max_length=255)),
                ('content_type', models.CharField(max_length=255)),
                ('http_accept', models.CharField(max_length=255)),
                ('http_accept_encoding', models.CharField(max_length=255)),
                ('http_accept_language', models.CharField(max_length=255)),
                ('http_host', models.CharField(max_length=255)),
                ('http_referer', models.CharField(max_length=2047)),
                ('http_user_agent', models.CharField(max_length=255)),
                ('remote_addr', models.CharField(max_length=255)),
                ('remote_host', models.CharField(max_length=255)),
                ('remote_user', models.CharField(max_length=255)),
                ('server_name', models.CharField(max_length=255)),
                ('server_port', models.CharField(max_length=255)),
                ('post_data', models.TextField()),
                ('get_data', models.TextField()),
                ('cookies', models.TextField()),
                ('encoding', models.CharField(max_length=255)),
                ('is_ajax', models.BooleanField()),
                ('user', models.ForeignKey(to=settings.AUTH_USER_MODEL, null=True)),
            ],
        ),
    ]



#!/usr/bin/env python
# vi: et sw=2 fileencoding=utf-8


from django.conf import settings

class RequestLoggerRouter(object):


  def db_for_read(self, model, **hints):
    if settings.REQUEST_LOGGER_CONNECTION:
      if model._meta.app_label == 'request_logger':
        return settings.REQUEST_LOGGER_CONNECTION
    return None
    # def db_for_read


  def db_for_write(self, model, **hints):
    if settings.REQUEST_LOGGER_CONNECTION:
      if model._meta.app_label == 'request_logger':
        return settings.REQUEST_LOGGER_CONNECTION
    return None
    # def db_for_write


  def allow_relation(self, obj1, obj2, **hints):
    if settings.REQUEST_LOGGER_CONNECTION:
      if obj1._meta.app_label == 'request_logger' or obj2._meta.app_label == 'request_logger':
        return True
    return None
    # def allow_relation


  def allow_migrate(self, db, app_label, model_name=None, **hints):
    if settings.REQUEST_LOGGER_CONNECTION:
      if app_label == 'request_logger':
          return db == settings.REQUEST_LOGGER_CONNECTION
      return False
    return None
    # def allow_migration


  # class AnittaRouter





# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-11-16 09:43
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import request_logger.models


class Migration(migrations.Migration):

    replaces = [('request_logger', '0001_initial'), ('request_logger', '0002_auto_20170918_1506'), ('request_logger', '0003_auto_20171115_1506')]

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='UserRequest',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('timestamp', models.DateTimeField(auto_now_add=True)),
                ('path', request_logger.models.TruncatingCharField(max_length=2047)),
                ('method', request_logger.models.TruncatingCharField(max_length=255)),
                ('scheme', request_logger.models.TruncatingCharField(max_length=255)),
                ('body', models.TextField()),
                ('content_length', request_logger.models.TruncatingCharField(max_length=255)),
                ('content_type', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_accept', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_accept_encoding', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_accept_language', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_host', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_referer', request_logger.models.TruncatingCharField(max_length=2047)),
                ('http_user_agent', request_logger.models.TruncatingCharField(max_length=255)),
                ('remote_addr', request_logger.models.TruncatingCharField(max_length=255)),
                ('remote_host', request_logger.models.TruncatingCharField(max_length=255)),
                ('remote_user', request_logger.models.TruncatingCharField(max_length=255)),
                ('server_name', request_logger.models.TruncatingCharField(max_length=255)),
                ('server_port', request_logger.models.TruncatingCharField(max_length=255)),
                ('post_data', models.TextField()),
                ('get_data', models.TextField()),
                ('cookies', models.TextField()),
                ('encoding', request_logger.models.TruncatingCharField(max_length=255)),
                ('is_ajax', models.BooleanField()),
                ('user', models.IntegerField(null=True)),
            ],
        ),
    ]



#!/usr/bin/env python
# vi: et sw=2 fileencoding=utf-8

from __future__ import unicode_literals

import json

from django.db.models import CharField, functions, Value
from django.utils.deprecation import MiddlewareMixin

from .models import UserRequest


class LoggerMiddleware(MiddlewareMixin, object):
  # pylint: disable=too-few-public-methods

  body_maksimipituus = 65536
  body_lohkokoko = 1024

  def process_request(self, request):
    # pylint: disable=no-self-use
    body = ''.join([
      merkki
      if 0 < ord(merkki) < 127
      else '.'
      for merkki in request.body[:self.body_maksimipituus]
    ])
    post = request.POST.copy()

    # suodata pois salasanat
    if 'password' in post:
      body = ''
      post['password'] = 'salasana'
    if 'password1' in post:
      body = ''
      post['password1'] = 'salasana'
    if 'password2' in post:
      body = ''
      post['password2'] = 'salasana'
    if 'salasana' in post:
      body = ''
      post['salasana'] = 'salasana'

    # luo uusi tietue
    user_request_id = UserRequest.objects.create(
      user=request.user.id if request.user.is_authenticated() else None,
      path=request.get_full_path()[:UserRequest._meta.get_field('path').max_length],
      method=request.method,
      scheme=request.scheme,
      body="",
      content_length=request.META.get("CONTENT_LENGTH", ""),
      content_type=request.META.get("CONTENT_TYPE", ""),
      http_accept=request.META.get("HTTP_ACCEPT", ""),
      http_accept_encoding=request.META.get("HTTP_ACCEPT_ENCODING", ""),
      http_accept_language=request.META.get("HTTP_ACCEPT_LANGUAGE", ""),
      http_host=request.META.get("HTTP_HOST", ""),
      http_referer=request.META.get("HTTP_REFERER", ""),
      http_user_agent=request.META.get("HTTP_USER_AGENT", ""),
      remote_addr=request.META.get("REMOTE_ADDR", ""),
      remote_host=request.META.get("REMOTE_HOST", ""),
      remote_user=request.META.get("REMOTE_USER", ""),
      server_name=request.META.get("SERVER_NAME", ""),
      server_port=request.META.get("SERVER_PORT", ""),
      post_data=json.dumps(request.POST),
      get_data=json.dumps(request.GET),
      cookies=json.dumps(request.COOKIES),
      encoding=request.encoding or "",
      is_ajax=request.is_ajax(),
    ).pk

    # lisää body pala kerrallaan
    for lohko in xrange(0, len(body), self.body_lohkokoko):
      UserRequest.objects.filter(
        pk=user_request_id
      ).update(
        body=functions.Concat(
          'body',
          Value(body[lohko:lohko+self.body_lohkokoko]),
          output_field=CharField(),
        ),
      )
    # def process_request

  # class LoggerMiddleware



from setuptools import setup, find_packages

setup(name='django-request-logger',
      version='0.1.8',
      description='Django middleware that logs http request information to database.',
      url='https://git.pispalanit.fi/pit/django-request-logger',
      author='Joni Saarinen',
      author_email='joni.saarinen@pispalanit.fi',
      license='MIT',
      packages=find_packages(),
      install_requires=[
          'Django',
      ],
zip_safe=False)



#!/usr/bin/env python
# vi: et sw=2 fileencoding=utf-8

from __future__ import unicode_literals

from django.apps import AppConfig


class RequestLoggerConfig(AppConfig):
  name = "request_logger"
  verbose_name = "Request logger for django"


  # class RequestLoggerConfig


